@@ -29,6 +29,9 @@ class Rethink_DBS(GeneralData):
         self.done_conn = False
         r = rdb
         r.set_loop_type('asyncio')
+        self.client_host = None
+        self.client_port = 0
+        self.session = None
         self.r = r
 
     def __repr__(self):
@@ -41,6 +44,18 @@ class Rethink_DBS(GeneralData):
         if self:
             self.save_log(msg, level)
 
+    @property
+    def client_address(self):
+        return (self.client_host, self.client_port)
+
+    @property
+    def active(self):
+        return self.client_host and self.client_port>0
+  
+    def clean_client(self):
+        self.client_host = None
+        self.client_port = 0
+
     async def async_connect(self, loop=None, *args, **kwargs):
         self.session = None
         try:
@@ -57,6 +72,9 @@ class Rethink_DBS(GeneralData):
                                                     host=dbhost,
                                                     port=dbport,
                                                     **kwargs)
+
+                self.client_host = self.session.client_address()
+                self.client_port = self.session.client_port()
                 self.done_conn = True
                 self.active_conn = True
                 self.logger.info(
@@ -93,8 +111,11 @@ class Rethink_DBS(GeneralData):
     async def close(self):
         if self.session:
             await self.session.close(noreply_wait=False)
+            self.session = None
+        self.clean_client()
 
     async def reconnect(self, wait=False):
+        self.clean_client()
         await self.session.reconnect(noreply_wait=wait)
 
     # database manage
