@@ -3,7 +3,7 @@ from rethinkdb import r
 import asyncio
 
 kwargs = {
-    'code': 'VALN',
+    'code': 'ATJN',
     'host': 'localhost',
     'port': 28015,
     'dbname': 'enu_data'
@@ -29,4 +29,5 @@ async def run(**kwargs):
         print("Error connection %s" % e)
         raise e
 
+
 asyncio.get_event_loop().run_until_complete(run(**kwargs))
